:orphan:

.. _command_history:

Condensed example of contributing code to Astropy
*************************************************

There are two versions:

* :ref:`with output` (easier to read along with)
* :ref:`no output` (easier to cut and paste from)

.. _with output:

Example, with output
====================

In this version the commands are on the lines that begin ``$`` others are
comments or output.

.. literalinclude:: command_history_with_output.sh
    :language: bash

.. _no output:

Example, no output
==================

.. literalinclude:: command_history.sh
    :language: bash
